@@ -8,6 +8,7 @@ from ..handlers.base import Handler
 from ..loader import HANDLERS, logger
 from ..objects.tg_objects import Update
 from ..requests.get_updates import get_updates
+from ..utils import cast
 
 
 def execute_handler(handler: Handler):
@@ -100,6 +101,7 @@ def process_update(update: Update) -> None:
 
 def process_updates(updates: list[Update]):
     for update in updates:
+        logger.info(cast(update, dict))
         Thread(target=lambda: process_update(update)).start()
 
 
